use "C:\Users\xzw\Desktop\AEJ_Code\stata\IntLibData.dta", clear 

// This code replicates Column 1 in Table B6


// compute industrial average value of key variables
bysort year cic_adj: egen LaborProd = mean(VA/PERSENG) // labor productivity
bysort year cic_adj: egen Avg_K     = mean(FA)         // size of fixed asset
bysort year cic_adj: egen Avg_LoanK = mean(LTL/FA)     // loan to capital ratio
bysort year cic_adj: egen Avg_Labor = mean(PERSENG)    // employment
bysort year cic_adj: egen AggVA_SOE_temp = sum(VA) if IsSOE==1 
bysort year cic_adj: egen AggVA_SOE = mean(AggVA_SOE_temp) // total output for SOEs in a particular industry
bysort year cic_adj: egen AggVA_POE_temp = sum(VA) if IsSOE==0
bysort year cic_adj: egen AggVA_POE = mean(AggVA_POE_temp) // total output for POEs in a particular industry

gen MPK = VA/FA

//sum Asi, de
_pctile MPK, nq(100)
drop if MPK<r(r1) | MPK>r(r99)


bysort cic_adj year: egen Avg_MPK = mean(MPK)

//bysort cic_adj year: egen temp_sd = sd(MPK) 
bysort cic_adj year: egen sd_MPK   = sd(MPK)

// compute SOE share in a particular industry in terms of output
gen VA_SOE_share = AggVA_SOE/(AggVA_POE+AggVA_SOE)

duplicates drop cic_adj year, force   // collapse the firm-level panel to the industry-level panel

xtset cic_adj year

gen IsPervIND = sd_MPK

// define interest rate wedge between benchmark loan rate and deposit rate
gen     phi = 2.5125 if year == 1998
replace phi = 3.1875 if year == 1999
replace phi = 3.6000 if year == 2000
replace phi = 3.6000 if year == 2001
replace phi = 3.3525 if year == 2002
replace phi = 3.3300 if year == 2003
replace phi = 3.3300 if year == 2004
replace phi = 3.3300 if year == 2005
replace phi = 3.5325 if year == 2006
replace phi = 3.4950 if year == 2007

// compute the different of key variables
gen Dphi = phi-l.phi

gen lnY = log(LaborProd)
gen DY_growth = lnY-l.lnY  // growth rate of industrial average of labor productivity


gen lnAvg_Labor = log(Avg_Labor)
gen Avg_Labor_growth= lnAvg_Labor-l.lnAvg_Labor // growth rate of industrial average of employment

gen lnAvg_K     = log(Avg_K)
gen Avg_K_growth = lnAvg_K-l.lnAvg_K  // growth rate of industrial average of capital

// define interaction terms
gen DphiIsPerv = Dphi*sd_MPK  
gen DphiSOEshare = Dphi*VA_SOE_share 

set cformat %9.3f
xtabond2 DY_growth Dphi  DphiIsPerv  IsPervIND   Avg_K_growth Avg_Labor_growth Avg_LoanK  Avg_MPK l.DY_growth, twostep small rob gmm(Avg_K_growth, lag(2 3) collapse)  gmm(Avg_Labor_growth, lag(2 3)  ) gmm(Avg_LoanK, lag(2 3) ) gmm(l.DY_growth,lag(2 3) ) gmm(VA_SOE_share, lag(2 3) )

